ColumnArg class final
One constructor column mapped to a schema accessor expression, plus its
read/write direction from @Column(readOnly:) / @Column(writeOnly:).
Constructors
Properties
- columnExpr → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNamed → bool
-
final
- paramName → String
-
final
- readOnly → bool
-
Excluded from INSERT and
UPDATE … SET(autoincrement PK, server default).final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- writeOnly → bool
-
Excluded from the generated SELECT row reader (the parameter must be
optional so its default is used).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited